==> xfxbase-2.6.24.tar.gz: lib/XMainDash_Base.dart <==
library dash;

import 'dart:async';
import 'dart:html';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:xcommonwidgets/xcommonwidgets.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'XAppStateBase.dart';
import 'XPlayer.dart';

class MainDashBase<T extends XAppStateBase> extends StatefulWidget {
  MainDashBase(this.urlParams, this.liDash, {Key? key, this.refreshDataTimerDuration}) : super(key: key);
  Duration? refreshDataTimerDuration;
  String urlParams;
  List<XDashboard> liDash = List<XDashboard>.empty(growable: true);
  @override
  State<MainDashBase<T>> createState() => MainDashBase_State<T>();

  ///Configurazione FontSize per le Label delle Dash
  static double fontSizeForTitleOfDashBoard = 20;
  static double fontSizeForTitleOfArea = 19;
  static double fontSizeForSubTitleOfArea = 20;
  static double height_TitleContainerOfArea = 40;

  static String? labelForNullDash;
  static Widget? labelForNullDash_Widget = null;

  ///Configurazione Altezze dei "Area_TitleContainer"
  static Color appColor_AppName = Color.fromARGB(255, 56, 140, 250);
  static Color appColor_BackGroundDark = Color.fromARGB(255, 29, 29, 29);
  static Color appColor_BackGroundLight = Color.fromARGB(255, 251, 244, 244);
}

///Configurazione Colors dell' App

class MainDashBase_State<T extends XAppStateBase> extends State<MainDashBase<T>> {
  Timer? timerRefreshALL;
  Timer? timerRefresh_PWA;
  late List<int> liDashBoardIndexesDecodedFromURL;
  late List<int> liDashBoardIndexesDecodedFromURL_timeOfView;
  int defaultTimeOutForDash = 10;
  String appName = "";
  String appVersion = "";
  String? clockUI;

  @override
  void initState() {
    if (widget.refreshDataTimerDuration == null) widget.refreshDataTimerDuration = Duration(seconds: 10);
    //Settare quali Dashboard andranno visualizzate all'interno della liDashboard
    liDashBoardIndexesDecodedFromURL = List<int>.empty(growable: true);
    liDashBoardIndexesDecodedFromURL_timeOfView = List<int>.empty(growable: true);

    ///Stabilisco quante Dash deve far vedere l'XPlayer e in che sequenza
    var res = initMainDash();
    XPlayer.liXDashBoard.addAll(widget.liDash);
    if (res) {
      //decodifico liDashBoardIndexesByURL
      // 1,3.30,0 >= la 1 per timeOut std, la 3 con timeOut 30sec, la 0
      var parts = widget.urlParams.split(',');
      print(parts);
      for (var dashCode in parts) {
        var timeOutDash = defaultTimeOutForDash;
        var idxDash = -1;
        var dashCodeParts = dashCode.split('.');
        print(dashCodeParts);

        if (dashCodeParts.length >= 1) {
          idxDash = int.parse(dashCodeParts[0]);
          if (dashCodeParts.length >= 2) timeOutDash = int.parse(dashCodeParts[1]);
        }
        if (idxDash >= 0) {
          liDashBoardIndexesDecodedFromURL.add(idxDash);
          liDashBoardIndexesDecodedFromURL_timeOfView.add(timeOutDash);
        }
      }
    } else {}
    //definisce elenco definitivo delle dash da visualizzare e apllica i timeOfView
    for (var i = 0; i < liDashBoardIndexesDecodedFromURL.length; i++) {
      XPlayer.liXDashBoard[liDashBoardIndexesDecodedFromURL[i]].timeOfView = liDashBoardIndexesDecodedFromURL_timeOfView[i];
    }

    ///init timers
    initTimers();

    ///inserisco nella lista di Dash dell'XPlayer tutte le Dash che dovrò visualizzare
    super.initState();
  }

  bool initMainDash() {
    return false;
  }

  initTimers() async {
    ///chiamerà il refreshall ogni tot secondi che inserisci sotto
    timerRefreshALL = Timer.periodic(widget.refreshDataTimerDuration!, (x) async => await refreshALL());
    // questo dovrebbe fare, insieme alle modifiche in index.html, scatenrare l'aggiornamento della PWA. FUNZIONA !!!!
    timerRefresh_PWA = Timer.periodic(Duration(hours: 1), (x) {
      //solo fuori da orari od'ufficio
      if (DateTime.now().hour < 7 || DateTime.now().hour == 13 || DateTime.now().hour > 18) window.location.reload();
    });
  }

  xStyleNumber_XDashBoardCounter(Color color) {
    return XStyles.xStyleText(fontSize: 40, activeBold: true, colorText: color);
  }

  xStyleLabel_XDashBoardCounter(Color color) {
    return XStyles.xStyleText(fontSize: 22, colorText: color);
  }

  get color_BaseWhite_XDashboardCounter => Colors.white;
  get iconSize_XDashboardCounter => 50;
  get color_XDashboardCounter => Colors.black;
  Future refreshALL() async {}
  xBuilder_Card(
    String label,
    Color color_ForCardAndIcon,
    String valueOfCard, {
    Color? color_ForLabel,
    IconData? icon,
    Image? imageAsIcon,
    TextStyle? numberStyle,
    TextStyle? labelStyle,
    Alignment? alignmentIconInCard = Alignment.centerLeft,
    Alignment? alignmentLabelInCard = Alignment.topLeft,
  }) {
    return XDashboardCounter(
      labelOfCard: label,
      styleNumberOfCard: numberStyle ?? xStyleNumber_XDashBoardCounter(color_ForCardAndIcon),
      styleLabelOfCard: labelStyle ?? xStyleLabel_XDashBoardCounter(color_ForLabel ?? color_BaseWhite_XDashboardCounter),
      visibleBottomBorderOfCard: false,
      valueOfCard: valueOfCard,
      colorCard: color_XDashboardCounter,
      iconSize: iconSize_XDashboardCounter,
      iconColor: color_ForCardAndIcon,
      imageAsIcon: imageAsIcon,
      alignmentIconInCard: Alignment.centerLeft,
      alignmentLabelInCard: Alignment.topLeft,
      icon: icon,
    );
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<T>(builder: (context, appState, _) {
      ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
      return Scaffold(
          backgroundColor: MainDashBase.appColor_BackGroundDark,
          body: XPlayer<T>(
            liDashBoardIndexesDecodedFromURL,
            appName: appName,
            appVersion: appVersion,
          ));
    });
  }
}

==> xfxbase-2.6.48.tar.gz: lib/XMainDash_Base.dart <==
library dash;

import 'dart:async';
import 'dart:html';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:xcommonwidgets/xcommonwidgets.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'XAppStateBase.dart';
import 'XPlayer.dart';

class MainDashBase<T extends XAppStateBase> extends StatefulWidget {
  MainDashBase(this.urlParams, this.liDash, {Key? key, this.refreshDataTimerDuration}) : super(key: key);
  Duration? refreshDataTimerDuration;
  String urlParams;
  List<XDashboard> liDash = List<XDashboard>.empty(growable: true);
  @override
  State<MainDashBase<T>> createState() => MainDashBase_State<T>();

  ///Configurazione FontSize per le Label delle Dash
  static double fontSizeForTitleOfDashBoard = 20;
  static double fontSizeForTitleOfArea = 19;
  static double fontSizeForSubTitleOfArea = 20;
  static double height_TitleContainerOfArea = 50;

  static String? labelForNullDash;
  static Widget? labelForNullDash_Widget = null;

  ///Configurazione Altezze dei "Area_TitleContainer"
  static Color appColor_AppName = Color.fromARGB(255, 56, 140, 250);
  static Color appColor_BackGroundDark = Color.fromARGB(255, 29, 29, 29);
  static Color appColor_BackGroundLight = Color.fromARGB(255, 251, 244, 244);
}

///Configurazione Colors dell' App

class MainDashBase_State<T extends XAppStateBase> extends State<MainDashBase<T>> {
  Timer? timerRefreshALL;
  Timer? timerRefresh_PWA;
  late List<int> liDashBoardIndexesDecodedFromURL;
  late List<int> liDashBoardIndexesDecodedFromURL_timeOfView;
  int defaultTimeOutForDash = 10;
  String appName = "";
  String appVersion = "";
  String? clockUI;

  @override
  void initState() {
    if (widget.refreshDataTimerDuration == null) widget.refreshDataTimerDuration = Duration(seconds: 10);
    //Settare quali Dashboard andranno visualizzate all'interno della liDashboard
    liDashBoardIndexesDecodedFromURL = List<int>.empty(growable: true);
    liDashBoardIndexesDecodedFromURL_timeOfView = List<int>.empty(growable: true);

    ///Stabilisco quante Dash deve far vedere l'XPlayer e in che sequenza
    var res = initMainDash();
    XPlayer.liXDashBoard.addAll(widget.liDash);
    if (res) {
      //decodifico liDashBoardIndexesByURL
      // 1,3.30,0 >= la 1 per timeOut std, la 3 con timeOut 30sec, la 0
      var parts = widget.urlParams.split(',');
      print(parts);
      for (var dashCode in parts) {
        var timeOutDash = defaultTimeOutForDash;
        var idxDash = -1;
        var dashCodeParts = dashCode.split('.');
        print(dashCodeParts);

        if (dashCodeParts.length >= 1) {
          idxDash = int.parse(dashCodeParts[0]);
          if (dashCodeParts.length >= 2) timeOutDash = int.parse(dashCodeParts[1]);
        }
        if (idxDash >= 0) {
          liDashBoardIndexesDecodedFromURL.add(idxDash);
          liDashBoardIndexesDecodedFromURL_timeOfView.add(timeOutDash);
        }
      }
    } else {}
    //definisce elenco definitivo delle dash da visualizzare e apllica i timeOfView
    for (var i = 0; i < liDashBoardIndexesDecodedFromURL.length; i++) {
      XPlayer.liXDashBoard[liDashBoardIndexesDecodedFromURL[i]].timeOfView = liDashBoardIndexesDecodedFromURL_timeOfView[i];
    }

    ///init timers
    initTimers();

    ///inserisco nella lista di Dash dell'XPlayer tutte le Dash che dovrò visualizzare
    super.initState();
  }

  bool initMainDash() {
    return false;
  }

  initTimers() async {
    ///chiamerà il refreshall ogni tot secondi che inserisci sotto
    timerRefreshALL = Timer.periodic(widget.refreshDataTimerDuration!, (x) async => await refreshALL());
    // questo dovrebbe fare, insieme alle modifiche in index.html, scatenrare l'aggiornamento della PWA. FUNZIONA !!!!
    timerRefresh_PWA = Timer.periodic(Duration(hours: 1), (x) {
      //solo fuori da orari od'ufficio
      if (DateTime.now().hour < 7 || DateTime.now().hour == 13 || DateTime.now().hour > 18) window.location.reload();
    });
  }

  xStyleNumber_XDashBoardCounter(Color color) {
    return XStyles.xStyleText(fontSize: 40, activeBold: true, colorText: color);
  }

  xStyleLabel_XDashBoardCounter(Color color) {
    return XStyles.xStyleText(fontSize: 22, colorText: color);
  }

  get color_BaseWhite_XDashboardCounter => Colors.white;
  get iconSize_XDashboardCounter => 50;
  get color_XDashboardCounter => Colors.black;
  Future refreshALL() async {}
  xBuilder_Card(
    String label,
    Color color_ForCardAndIcon,
    String valueOfCard, {
    Color? color_ForLabel,
    IconData? icon,
    Image? imageAsIcon,
    TextStyle? numberStyle,
    TextStyle? labelStyle,
    double? iconSize,
    Alignment? alignmentIconInCard = Alignment.centerLeft,
    Alignment? alignmentLabelInCard = Alignment.topLeft,
  }) {
    return XDashboardCounter(
      labelOfCard: label,
      styleNumberOfCard: numberStyle ?? xStyleNumber_XDashBoardCounter(color_ForCardAndIcon),
      styleLabelOfCard: labelStyle ?? xStyleLabel_XDashBoardCounter(color_ForLabel ?? color_BaseWhite_XDashboardCounter),
      visibleBottomBorderOfCard: false,
      valueOfCard: valueOfCard,
      colorCard: color_XDashboardCounter,
      iconSize: iconSize ?? iconSize_XDashboardCounter,
      iconColor: color_ForCardAndIcon,
      imageAsIcon: imageAsIcon,
      alignmentIconInCard: Alignment.centerLeft,
      alignmentLabelInCard: Alignment.topLeft,
      icon: icon,
    );
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<T>(builder: (context, appState, _) {
      ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
      return Scaffold(
          backgroundColor: MainDashBase.appColor_BackGroundDark,
          body: XPlayer<T>(
            liDashBoardIndexesDecodedFromURL,
            appName: appName,
            appVersion: appVersion,
          ));
    });
  }
}
